@@ -1,24 +1,20 @@
+import re
 from datetime import datetime, timedelta
 
-from beancount.ingest import importer
-from beancount.core import data
-from beancount.core import amount
-from beancount.core.number import D
-from beancount.ingest.importers.mixins import identifier
-
 import camelot
-import re
+from beancount.core import amount, data
+from beancount.core.number import D
+from beancount.ingest import importer
+from beancount.ingest.importers.mixins import identifier
 
 
 class Importer(identifier.IdentifyMixin, importer.ImporterProtocol):
     """An importer for Cembra Card Statement PDF files."""
 
     def __init__(self, regexps, account):
-        identifier.IdentifyMixin.__init__(self, matchers=[
-            ('filename', regexps)
-        ])
+        identifier.IdentifyMixin.__init__(self, matchers=[("filename", regexps)])
         self.account = account
-        self.currency = 'CHF'
+        self.currency = "CHF"
 
     def file_account(self, file):
         return self.account
@@ -28,14 +24,14 @@ class Importer(identifier.IdentifyMixin, importer.ImporterProtocol):
         return data.Transaction(
             meta,
             date,
-            '*',
-            '',
+            "*",
+            "",
             text,
             data.EMPTY_SET,
             data.EMPTY_SET,
             [
                 data.Posting(self.account, amt, None, None, None, None),
-            ]
+            ],
         )
 
     def createBalanceEntry(self, file, date, amt):
@@ -45,7 +41,9 @@ class Importer(identifier.IdentifyMixin, importer.ImporterProtocol):
     def extract(self, file, existing_entries):
         entries = []
 
-        tables = camelot.read_pdf(file.name, pages='2-end', flavor='stream', table_areas=['50,700,560,50'])
+        tables = camelot.read_pdf(
+            file.name, pages="2-end", flavor="stream", table_areas=["50,700,560,50"]
+        )
         for table in tables:
             df = table.df
 
@@ -56,11 +54,17 @@ class Importer(identifier.IdentifyMixin, importer.ImporterProtocol):
             for index, row in df.iterrows():
 
                 trx_date, book_date, text, credit, debit = tuple(row)
-                trx_date, book_date, text, credit, debit = trx_date.strip(), book_date.strip(), text.strip(), credit.strip(), debit.strip()
+                trx_date, book_date, text, credit, debit = (
+                    trx_date.strip(),
+                    book_date.strip(),
+                    text.strip(),
+                    credit.strip(),
+                    debit.strip(),
+                )
 
                 # Transaction entry
                 try:
-                    book_date = datetime.strptime(book_date, '%d.%m.%Y').date()
+                    book_date = datetime.strptime(book_date, "%d.%m.%Y").date()
                 except Exception:
                     book_date = None
 
@@ -73,8 +77,10 @@ class Importer(identifier.IdentifyMixin, importer.ImporterProtocol):
 
                 # Balance entry
                 try:
-                    book_date = re.search(r'Saldo per (\d\d\.\d\d\.\d\d\d\d) zu unseren Gunsten CHF', text).group(1)
-                    book_date = datetime.strptime(book_date, '%d.%m.%Y').date()
+                    book_date = re.search(
+                        r"Saldo per (\d\d\.\d\d\.\d\d\d\d) zu unseren Gunsten CHF", text
+                    ).group(1)
+                    book_date = datetime.strptime(book_date, "%d.%m.%Y").date()
                     # add 1 day: cembra provides balance at EOD, but beancount checks it at SOD
                     book_date = book_date + timedelta(days=1)
                 except Exception:
